package com.ruoyi.system.controller;

import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import com.ruoyi.common.core.web.domain.AjaxResult;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.core.utils.poi.ExcelUtil;
import javax.servlet.http.HttpServletResponse;
import org.springframework.web.bind.annotation.GetMapping;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import java.util.List;
import com.ruoyi.common.core.web.page.TableDataInfo;
import com.ruoyi.system.domain.SnCard;
import org.springframework.beans.factory.annotation.Autowired;
import com.ruoyi.system.service.ISnCardService;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.core.web.controller.BaseController;

@RestController
@RequestMapping({ "/SnCard" })
public class SnCardController extends BaseController
{
    @Autowired
    private ISnCardService snCardService;
    
    @RequiresPermissions({ "system:SnCard:list" })
    @GetMapping({ "/list" })
    public TableDataInfo list(final SnCard snCard) {
        this.startPage();
        final List<SnCard> list = this.snCardService.selectSnCardList(snCard);
        return this.getDataTable((List)list);
    }
    
    @RequiresPermissions({ "system:SnCard:export" })
    @Log(title = "卡密", businessType = BusinessType.EXPORT)
    @PostMapping({ "/export" })
    public void export(final HttpServletResponse response, final SnCard snCard) {
        final List<SnCard> list = this.snCardService.selectSnCardList(snCard);
        final ExcelUtil<SnCard> util = (ExcelUtil<SnCard>)new ExcelUtil((Class)SnCard.class);
        util.exportExcel(response, (List)list, "卡密数据");
    }
    
    @RequiresPermissions({ "system:SnCard:query" })
    @GetMapping({ "/{cardId}" })
    public AjaxResult getInfo(@PathVariable("cardId") final Long cardId) {
        return this.success((Object)this.snCardService.selectSnCardByCardId(cardId));
    }
    
    @RequiresPermissions({ "system:SnCard:add" })
    @Log(title = "卡密", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody final SnCard snCard) {
        if (snCard.getDealerId() == null) {
            return this.error("经销商ID不能为空");
        }
        if (snCard.getType() == null || snCard.getType() < 1) {
            return this.error("卡密数量有误");
        }
        if (snCard.getNumber() == null || snCard.getNumber() < 1) {
            return this.error("卡密数量有误");
        }
        return this.snCardService.insertSnCard(snCard);
    }
    
    @RequiresPermissions({ "system:SnCard:edit" })
    @Log(title = "卡密", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody final SnCard snCard) {
        return this.toAjax(this.snCardService.updateSnCard(snCard));
    }
    
    @RequiresPermissions({ "system:SnCard:remove" })
    @Log(title = "卡密", businessType = BusinessType.DELETE)
    @DeleteMapping({ "/{cardIds}" })
    public AjaxResult remove(@PathVariable final Long[] cardIds) {
        return this.toAjax(this.snCardService.deleteSnCardByCardIds(cardIds));
    }
}
